@@ -46,6 +46,9 @@ extern struct libdax_msgs *libdax_messenger;
 static struct burn_drive drive_array[255];
 static int drivetop = -1;
 
+/* ts A80410 : in init.c */
+extern int burn_support_untested_profiles;
+
 /* ts A61021 : the unspecific part of sg.c:enumerate_common()
 */
 int burn_setup_drive(struct burn_drive *d, char *fname)
@@ -58,6 +61,7 @@ int burn_setup_drive(struct burn_drive *d, char *fname)
 	d->released = 1;
 	d->stdio_fd = -1;
 	d->status = BURN_DISC_UNREADY;
+	d->do_stream_recording = 0;
 	return 1;
 }
 
@@ -588,7 +592,7 @@ void burn_disc_erase_sync(struct burn_drive *d, int fast)
 
 /*
    @param flag: bit0 = fill formatted size with zeros
-                bit1, bit2 , bit4, bit7 - bit15 are for d->format_unit()
+                bit1, bit2 , bit4, bit5, bit7 - bit15 are for d->format_unit()
 */
 void burn_disc_format_sync(struct burn_drive *d, off_t size, int flag)
 {
@@ -611,7 +615,7 @@ void burn_disc_format_sync(struct burn_drive *d, off_t size, int flag)
 	d->cancel = 0;
 	d->busy = BURN_DRIVE_FORMATTING;
 
-	ret = d->format_unit(d, size, flag & 0xff96); /* forward bits */
+	ret = d->format_unit(d, size, flag & 0xfff6); /* forward bits */
 	if (ret <= 0)
 		d->cancel = 1;
 
@@ -1256,7 +1260,7 @@ int burn_drive_grab_dummy(struct burn_drive_info *drive_infos[], char *fname)
 		d->current_is_supported_profile = 1;
 		d->block_types[BURN_WRITE_TAO] = BURN_BLOCK_MODE1;
 		d->block_types[BURN_WRITE_SAO] = BURN_BLOCK_SAO;
-		d->media_capacity_remaining = size;
+		burn_drive_set_media_capacity_remaining(d, size);
 
 		/* >>> ? open file for a test ? (>>> beware of "-" = stdin) */;
 
@@ -1868,8 +1872,8 @@ off_t burn_disc_available_space(struct burn_drive *d,
 		return 0;
 	if (d->drive_role != 1) {
 		if (d->media_capacity_remaining <= 0)
-			d->media_capacity_remaining = 
-			((off_t) (512 * 1024 * 1024 - 1) * (off_t) 2048);
+			burn_drive_set_media_capacity_remaining(d,
+			  (off_t) (512 * 1024 * 1024 - 1) * (off_t) 2048);
 	} else {
 		if (o != NULL)
 			d->send_write_parameters(d, o);
@@ -2101,7 +2105,7 @@ int burn_disc_get_multi_caps(struct burn_drive *d, enum burn_write_types wt,
 		o->start_adr = 1;
 		size = d->media_capacity_remaining;
 		burn_os_stdio_capacity(d->devname, &size);
-		d->media_capacity_remaining = size;
+		burn_drive_set_media_capacity_remaining(d, size);
 		o->start_range_high = size;
 		o->start_alignment = 2048; /* imposting a drive, not a file */
 		o->might_do_sao = 4;
@@ -2166,9 +2170,12 @@ int burn_disc_get_multi_caps(struct burn_drive *d, enum burn_write_types wt,
 		if (wt == BURN_WRITE_NONE || wt == BURN_WRITE_SAO ||
 		    wt == BURN_WRITE_TAO)
 			o->might_simulate = 1;
-	} else if (d->current_profile == 0x12 || d->current_profile == 0x13 ||
-			d->current_profile == 0x1a) {
-		/* DVD-RAM, overwriteable DVD-RW, DVD+RW */
+	} else if (d->current_profile == 0x12 ||
+			d->current_profile == 0x13 ||
+			d->current_profile == 0x1a ||
+			d->current_profile == 0x43 
+	          ) {
+		/* DVD-RAM, overwriteable DVD-RW, DVD+RW, BD-RE */
 		o->start_adr = 1;
 		ret = burn_disc_get_formats(d, &status, &size, &dummy,
 					&num_formats);
@@ -2187,6 +2194,8 @@ int burn_disc_get_multi_caps(struct burn_drive *d, enum burn_write_types wt,
 				}
 				if (i >= num_formats) /* not expandable */
 					o->start_range_high -= 32 * 1024;
+				if (o->start_range_high < 0)
+					o->start_range_high = 0;
 			} else {
 				o->start_alignment = 2 * 1024;
 				if (d->best_format_size - 2048 >
@@ -2450,3 +2459,11 @@ int burn_drive_find_by_thread_pid(struct burn_drive **d, pid_t pid)
 }
 
 
+/* ts A80422 : centralizing this setting for debugging purposes
+*/
+int burn_drive_set_media_capacity_remaining(struct burn_drive *d, off_t value)
+{
+	d->media_capacity_remaining = value;
+	return 1;
+}
+
