@@ -260,6 +260,37 @@ static void sg_select_device_family(void)
 }
 
 
+/* ts A80701 */
+/* This cares for the case that no /dev/srNN but only /dev/scdNN exists.
+   A theoretical case which has its complement in SuSE 10.2 having
+   /dev/sr but not /dev/scd.
+*/
+static int sg_exchange_scd_for_sr(char *fname, int flag)
+{
+	struct stat stbuf;
+	char scd[17], msg[160];
+
+	if (burn_sg_use_family != 0 || strncmp(fname, "/dev/sr", 7)!=0 ||
+	    strlen(fname)>9 || strlen(fname)<8)
+		return 2;
+	if (fname[7] < '0' || fname[7] > '9')
+		return 2;
+	if (fname [8] != 0 && (fname[7] < '0' || fname[7] > '9'))
+		return 2;
+	if (stat(fname, &stbuf) != -1)
+		return 2;
+	strcpy(scd, "/dev/scd");
+	strcpy(scd + 8, fname + 7);
+	if (stat(scd, &stbuf) == -1)
+		return 2;
+	sprintf(msg, "%s substitutes for non-existent %s", scd, fname);
+	libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+		LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH, msg, 0, 0);
+	strcpy(fname, scd);
+	return 1;
+}
+
+
 static int sgio_test(int fd)
 {
 	unsigned char test_ops[] = { 0, 0, 0, 0, 0, 0 };
@@ -279,6 +310,33 @@ static int sgio_test(int fd)
 static int sg_handle_busy_device(char *fname, int os_errno)
 {
 	char msg[4096];
+	struct stat stbuf;
+	int looks_like_hd= 0, fd, ret;
+
+	/* ts A80713 :
+	   check existence of /dev/hdX1 as hint for hard disk rather than CD
+	   Hint by Giulio Orsero: check /proc/ide/hdX/media for "disk"
+	*/
+	if (strncmp(fname, "/dev/hd", 7)==0) {
+		sprintf(msg, "%s1", fname);
+		if (stat(msg, &stbuf) != -1)
+			looks_like_hd= 1;
+		sprintf(msg, "/proc/ide/hd%c/media", fname[7]);
+		fd = open(msg, O_RDONLY);
+		if (fd != -1) {
+			ret = read(fd, msg, 10);
+			if (ret < 0)
+				ret = 0;
+			msg[ret]= 0;
+			close(fd);
+			if (strncmp(msg, "disk\n", 5) == 0 ||
+			    strcmp(msg, "disk") == 0)
+				looks_like_hd= 2;
+			else if (strncmp(msg, "cdrom\n", 6) == 0 ||
+			         strcmp(msg, "cdrom") == 0)
+				looks_like_hd= 0;
+		}
+	}
 
 	/* ts A60814 : i saw no way to do this more nicely */ 
 	if (burn_sg_open_abort_busy) {
@@ -292,10 +350,26 @@ static int sg_handle_busy_device(char *fname, int os_errno)
 	}
 
 	/* ts A60924 : now reporting to libdax_msgs */
-	sprintf(msg, "Cannot open busy device '%s'", fname);
-	libdax_msgs_submit(libdax_messenger, -1, 0x00020001,
-			LIBDAX_MSGS_SEV_SORRY, LIBDAX_MSGS_PRIO_LOW,
-			msg, os_errno, 0);
+	if (looks_like_hd == 2) { /* is surely hard disk */
+		;
+	} else if (looks_like_hd) {
+		sprintf(msg, "Could not examine busy device '%s'", fname);
+		libdax_msgs_submit(libdax_messenger, -1, 0x0002015a,
+				LIBDAX_MSGS_SEV_NOTE, LIBDAX_MSGS_PRIO_LOW,
+				msg, os_errno, 0);
+		sprintf(msg,
+	"Busy '%s' seems to be a hard disk, as '%s1' exists. But better check.",
+				fname, fname);
+		libdax_msgs_submit(libdax_messenger, -1, 0x0002015b,
+				LIBDAX_MSGS_SEV_HINT, LIBDAX_MSGS_PRIO_LOW,
+				msg, 0, 0);
+
+	} else {
+		sprintf(msg, "Cannot open busy device '%s'", fname);
+		libdax_msgs_submit(libdax_messenger, -1, 0x00020001,
+				LIBDAX_MSGS_SEV_SORRY, LIBDAX_MSGS_PRIO_LOW,
+				msg, os_errno, 0);
+	}
 	return 1;
 }
 
@@ -646,7 +720,7 @@ static void sg_enumerate(void)
 	int i, fd, sibling_fds[BURN_OS_SG_MAX_SIBLINGS], sibling_count= 0, ret;
 	int sid_ret = 0;
 	int bus_no= -1, host_no= -1, channel_no= -1, target_no= -1, lun_no= -1;
-	char fname[10];
+	char fname[17];
 	char sibling_fnames[BURN_OS_SG_MAX_SIBLINGS][BURN_OS_SG_MAX_NAMELEN];
 
         sg_select_device_family();
@@ -661,6 +735,9 @@ static void sg_enumerate(void)
 	for (i = 0; i < 32; i++) {
 		sprintf(fname, linux_sg_device_family, i);
 
+		/* ts A80702 */
+		sg_exchange_scd_for_sr(fname, 0);
+
 		if (linux_sg_enumerate_debug)
 		  fprintf(stderr, "libburn_debug: %s : ", fname);
 
@@ -893,6 +970,10 @@ int sg_give_next_adr(burn_drive_enumerator_t *idx,
 	if (adr_size < 10)
 		return -1;
 	sprintf(adr, linux_sg_device_family, *idx);
+
+	/* ts A80702 */
+	sg_exchange_scd_for_sr(adr, 0);
+
 	return 1;
 next_ata:;
 	baseno += sg_limit;
@@ -1378,7 +1459,6 @@ int sg_is_enumerable_adr(char *adr)
 			sg_give_next_adr(&idx, fname, sizeof(fname), -1);
 			return 1;
 		}
-
 	}
 	sg_give_next_adr(&idx, fname, sizeof(fname), -1);
 	return(0);
