@@ -49,6 +49,24 @@
 extern struct libdax_msgs *libdax_messenger;
 
 
+/* The maximum output size to be used with CD media. This is also curbed
+   by BURN_OS_TRANSPORT_BUFFER_SIZE. The smaller number gets into effect.
+*/ 
+#define Libburn_cd_obS (32 * 1024)
+
+/* The size to be used with DVD media.
+*/
+#define Libburn_dvd_obS (32 * 1024)
+
+/* The size to be used with BD-RE media in normal, not streamed mode.
+*/
+#define Libburn_bd_re_obS (32 * 1024)
+
+/* The size to be used with BD-RE media in streamed mode.
+*/
+#define Libburn_bd_re_streamed_obS (64 * 1024)
+
+
 static int type_to_ctrl(int mode)
 {
 	int ctrl = 0;
@@ -1401,7 +1419,6 @@ int burn_disc_setup_dvd_plus_rw(struct burn_write_opts *o,
 {
 	struct burn_drive *d = o->drive;
 	int ret;
-	char msg[160];
 
 	if (d->bg_format_status==0 || d->bg_format_status==1) {
 		d->busy = BURN_DRIVE_FORMATTING;
@@ -1412,16 +1429,6 @@ int burn_disc_setup_dvd_plus_rw(struct burn_write_opts *o,
 		d->busy = BURN_DRIVE_WRITING;
 		d->needs_close_session = 1;
 	}
-	d->nwa = 0;
-	if (o->start_byte >= 0) {
-		d->nwa = o->start_byte / 2048;
-
-		sprintf(msg, "Write start address is  %d * 2048", d->nwa);
-		libdax_msgs_submit(libdax_messenger, d->global_index,
-				0x00020127,
-				LIBDAX_MSGS_SEV_NOTE, LIBDAX_MSGS_PRIO_HIGH,
-				msg, 0, 0);
-	}
 
 	/* >>> perform OPC if needed */;
 
@@ -1511,7 +1518,7 @@ int burn_disc_setup_dvd_plus_r(struct burn_write_opts *o,
 }
 
 
-/* ts A61218 - A70129 */
+/* ts A61218 - A70415 */
 int burn_dvd_write_sync(struct burn_write_opts *o,
 				 struct burn_disc *disc)
 {
@@ -1523,6 +1530,9 @@ int burn_dvd_write_sync(struct burn_write_opts *o,
 
 	d->needs_close_session = 0;
 
+	/* buffer flush trigger for sector.c:get_sector() */
+	o->obs = Libburn_dvd_obS;
+
 	if (d->current_profile == 0x1a || d->current_profile == 0x12 ||
 	    d->current_profile == 0x43) { 
 		/* DVD+RW , DVD-RAM , BD-RE */
@@ -1538,7 +1548,24 @@ int burn_dvd_write_sync(struct burn_write_opts *o,
 				msg, 0, 0);
 			goto early_failure;
 		}
+		d->nwa = 0;
+		if (o->start_byte >= 0) {
+			d->nwa = o->start_byte / 2048;
+			sprintf(msg, "Write start address is  %d * 2048",
+				d->nwa);
+			libdax_msgs_submit(libdax_messenger, d->global_index,
+				0x00020127,
+				LIBDAX_MSGS_SEV_NOTE, LIBDAX_MSGS_PRIO_HIGH,
+				msg, 0, 0);
+		}
 		o->obs_pad = 0; /* no filling-up of track's last 32k buffer */
+		if (d->current_profile == 0x43) /* BD-RE */
+			o->obs = Libburn_bd_re_obS;
+		if (d->do_stream_recording) {
+			o->obs_pad = 1;
+			if (d->current_profile == 0x43) /* BD-RE */
+				o->obs = Libburn_bd_re_streamed_obS;
+		}
 
 	} else if (d->current_profile == 0x13) {
 		 /* DVD-RW Restricted Overwrite */
@@ -1611,7 +1638,11 @@ int burn_dvd_write_sync(struct burn_write_opts *o,
 		/* ??? padding needed ??? cowardly doing it for now */
 		o->obs_pad = 1; /* fill-up track's last 32k buffer */
 	}
-	o->obs = 32*1024; /* buffer flush trigger for sector.c:get_sector() */
+
+	sprintf(msg, "dvd/bd Profile= %2.2Xh , obs= %d , obs_pad= %d",
+		d->current_profile, o->obs, o->obs_pad);
+	libdax_msgs_submit(libdax_messenger, d->global_index, 0x00000002,
+		LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_ZERO, msg, 0, 0);
 
 	for (i = 0; i < disc->sessions; i++) {
 		/* update progress */
@@ -1978,6 +2009,9 @@ void burn_disc_write_sync(struct burn_write_opts *o, struct burn_disc *disc)
 	/* ts A61224 */
 	burn_disc_init_write_status(o, disc); /* must be done very early */
 
+	/* ts A80412 */
+	d->do_stream_recording = o->do_stream_recording;
+
 	d->buffer = &buf;
 	memset(d->buffer, 0, sizeof(struct buffer));
 	d->rlba = -150;
@@ -1988,16 +2022,26 @@ void burn_disc_write_sync(struct burn_write_opts *o, struct burn_disc *disc)
 		ret = burn_stdio_write_sync(o, disc);
 		if (ret <= 0)
 			goto fail_wo_sync;
-		return;
+		goto ex;
 	}
 	/* ts A61218 */
 	if (! d->current_is_cd_profile) {
 		ret = burn_dvd_write_sync(o, disc);
 		if (ret <= 0)
 			goto fail_wo_sync;
-		return;
+		goto ex;
 	}
 
+	/* ts A70521 : Linux 2.4 USB audio fails with 64 kiB */
+	/* ts A80414 : might need 64 kiB for BD-RE streaming */
+        /* buffer flush trigger for sector.c:get_sector() */
+	o->obs = Libburn_cd_obS;
+
+	sprintf(msg, "cd Profile= %2.2Xh , obs= %d , obs_pad= %d",
+		d->current_profile, o->obs, o->obs_pad);
+	libdax_msgs_submit(libdax_messenger, d->global_index, 0x00000002,
+		LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_ZERO, msg, 0, 0);
+
 	/* ts A70218 */
 	if (o->write_type == BURN_WRITE_SAO) {
 		for (i = 0 ; i < disc->session[0]->tracks; i++) {
@@ -2148,7 +2192,7 @@ return crap.  so we send the command, then ignore the result.
 
 	/* ts A61012 : This return was traditionally missing. I suspect this
 			to have caused Cdrskin_eject() failures */
-	return;
+	goto ex;
 
 fail:
 	d->sync_cache(d);
@@ -2160,6 +2204,9 @@ fail_wo_sync:;
 			"Burn run failed", 0, 0);
 	d->cancel = 1;
 	d->busy = BURN_DRIVE_IDLE;
+ex:;
+	d->do_stream_recording = 0;
+	return;
 }
 
 /* ts A70811 : API function */
